@@ -16,17 +16,26 @@ class CPUAdamBuilder(TorchCPUOpBuilder):
         return f'deepspeed.ops.adam.{self.NAME}_op'
 
     def sources(self):
+        if self.build_for_cpu:
+            return ['csrc/adam/cpu_adam.cpp']
+
         return ['csrc/adam/cpu_adam.cpp', 'csrc/common/custom_cuda_kernel.cu']
 
     def libraries_args(self):
         args = super().libraries_args()
+        if self.build_for_cpu:
+            return args
+
         if not self.is_rocm_pytorch():
             args += ['curand']
+
         return args
 
     def include_paths(self):
         import torch
-        if not self.is_rocm_pytorch():
+        if self.build_for_cpu:
+            CUDA_INCLUDE = []
+        elif not self.is_rocm_pytorch():
             CUDA_INCLUDE = [os.path.join(torch.utils.cpp_extension.CUDA_HOME, "include")]
         else:
             CUDA_INCLUDE = [
