@@ -1,14 +1,9 @@
 '''
 Copyright 2020 The Microsoft DeepSpeed Team
 '''
-import json
-import math
-import importlib
 import torch
-from torch import nn
-from torch.autograd import Function
 
-from ..op_builder import QuantizerBuilder
+from deepspeed.ops.op_builder import QuantizerBuilder
 
 # Cuda modules will be imported if needed
 quantizer_cuda_module = None
