@@ -4,8 +4,7 @@ Copyright 2022 The Microsoft DeepSpeed Team
 
 from typing import Optional
 import torch
-
-from ... import op_builder
+from deepspeed.ops.op_builder import SpatialInferenceBuilder
 
 spatial_cuda_module = None
 
@@ -16,7 +15,7 @@ def nhwc_bias_add(activation: torch.Tensor,
                   other_bias: Optional[torch.Tensor] = None) -> torch.Tensor:
     global spatial_cuda_module
     if spatial_cuda_module is None:
-        spatial_cuda_module = op_builder.SpatialInferenceBuilder().load()
+        spatial_cuda_module = SpatialInferenceBuilder().load()
 
     if other is None:
         return spatial_cuda_module.nhwc_bias_add(activation, bias)
