@@ -4,12 +4,12 @@ Copyright 2022 The Microsoft DeepSpeed Team
 
 import torch
 import torch.nn as nn
-from ... import op_builder
 
 from deepspeed import module_inject
 from .diffusers_attention import DeepSpeedDiffusersAttention
 from .bias_add import nhwc_bias_add
 from .diffusers_2d_transformer import Diffusers2DTransformerConfig
+from deepspeed.ops.op_builder import InferenceBuilder, SpatialInferenceBuilder
 
 # Ops will be loaded on demand
 transformer_cuda_module = None
@@ -19,14 +19,14 @@ spatial_cuda_module = None
 def load_transformer_module():
     global transformer_cuda_module
     if transformer_cuda_module is None:
-        transformer_cuda_module = op_builder.InferenceBuilder().load()
+        transformer_cuda_module = InferenceBuilder().load()
     return transformer_cuda_module
 
 
 def load_spatial_module():
     global spatial_cuda_module
     if spatial_cuda_module is None:
-        spatial_cuda_module = op_builder.SpatialInferenceBuilder().load()
+        spatial_cuda_module = SpatialInferenceBuilder().load()
     return spatial_cuda_module
 
 
@@ -76,8 +76,8 @@ class DeepSpeedDiffusersTransformerBlock(nn.Module):
             self.attn_1.do_out_bias = False
             self.attn_1_bias = self.attn_1.attn_ob
         else:
-            self.attn_1_bias = nn.Paramaeter(torch.zeros_like(self.norm2_g),
-                                             requires_grad=False)
+            self.attn_1_bias = nn.Parameter(torch.zeros_like(self.norm2_g),
+                                            requires_grad=False)
 
         # Pull the bias in if we can
         if isinstance(self.attn_2, DeepSpeedDiffusersAttention):
@@ -90,7 +90,14 @@ class DeepSpeedDiffusersTransformerBlock(nn.Module):
         self.transformer_cuda_module = load_transformer_module()
         load_spatial_module()
 
-    def forward(self, hidden_states, context=None, timestep=None):
+    def forward(self, hidden_states, context=None, timestep=None, **kwargs):
+        # In v0.12.0 of diffuser, several new kwargs were added. Capturing
+        # those with kwargs to maintain backward compatibility
+
+        # In v0.11.0 of diffusers, the kwarg was changed from 'context' to 'encoder_hidden_states'
+        # This is so we can support older and newer versions of diffusers
+        if "encoder_hidden_states" in kwargs and kwargs["encoder_hidden_states"] != None:
+            context = kwargs["encoder_hidden_states"]
 
         out_norm_1 = self.transformer_cuda_module.layer_norm(hidden_states,
                                                              self.norm1_g,
@@ -98,14 +105,14 @@ class DeepSpeedDiffusersTransformerBlock(nn.Module):
                                                              self.norm1_eps)
         out_attn_1 = self.attn_1(out_norm_1)
 
-        out_norm_2, out_attn_1 = self.transformer_cuda_module.layer_norm_residual_store(out_attn_1,
+        out_norm_2, out_attn_1 = self.transformer_cuda_module.layer_norm_residual_store_pre_ln_res(out_attn_1,
                                                                  self.attn_1_bias,
                                                                  hidden_states,
                                                                  self.norm2_g,
                                                                  self.norm2_b,
                                                                  self.norm2_eps)
         out_attn_2 = self.attn_2(out_norm_2, context=context)
-        out_norm_3, out_attn_2 = self.transformer_cuda_module.layer_norm_residual_store(out_attn_2,
+        out_norm_3, out_attn_2 = self.transformer_cuda_module.layer_norm_residual_store_pre_ln_res(out_attn_2,
                                                                  self.attn_2_bias,
                                                                  out_attn_1,
                                                                  self.norm3_g,
