@@ -16,9 +16,13 @@ from math import floor
 from bisect import bisect_left
 
 import torch
-from torch._six import inf
 from deepspeed import comm as dist
 
+try:
+    from torch._six import inf as inf
+except ModuleNotFoundError:
+    from torch import inf as inf
+
 from deepspeed.utils import groups, logger
 from deepspeed.runtime.constants import PIPE_REPLICATED
 from numpy import prod
